@@ -14,10 +14,10 @@ mod exist;
 mod fetch;
 /// Holds the contract for insert access operation.
 mod insert;
+/// Holds the contract for iter access operations.
+mod iter;
 /// Holds the contract for multiple fetch access operation.
 mod multi_fetch;
-/// Holds the contract for stream access operations.
-mod stream;
 /// Holds the contract for truncate access operations.
 mod truncate;
 
@@ -26,6 +26,6 @@ pub use delete::Delete;
 pub use exist::Exist;
 pub use fetch::Fetch;
 pub use insert::Insert;
+pub use iter::AsIterator;
 pub use multi_fetch::MultiFetch;
-pub use stream::AsStream;
 pub use truncate::Truncate;
